@@ -2,23 +2,23 @@
 R help system.
 
 """
-import os, itertools
-
+import sys, os
+from collections import namedtuple
 import sqlite3
 
 import rpy2.rinterface as rinterface
 from rpy2.rinterface import StrSexpVector
 
-import packages
-import rpy2.rlike.container as rlc
+from rpy2.robjects.packages_utils import get_packagepath, _libpaths, _packages
+from collections import OrderedDict
+
+if sys.version_info[0] == 2:
+    range = xrange
 
 tmp = rinterface.baseenv['R.Version']()
 tmp_major = int(tmp[tmp.do_slot('names').index('major')][0])
 tmp_minor = float(tmp[tmp.do_slot('names').index('minor')][0])
-if (tmp_major > 2) or (tmp_major == 2 and tmp_minor >= 13):
-    readRDS = rinterface.baseenv['readRDS']
-else:
-    readRDS = rinterface.baseenv['.readRDS']
+readRDS = rinterface.baseenv['readRDS']
 
 del(tmp)
 del(tmp_major)
@@ -34,6 +34,7 @@ def quiet_require(name, lib_loc = None):
     expr = rinterface.parse(expr_txt)
     ok = _eval(expr)
     return ok
+
 quiet_require('tools')
 _get_namespace = rinterface.baseenv['getNamespace']
 _lazyload_dbfetch = rinterface.baseenv['lazyLoadDBfetch']
@@ -88,7 +89,7 @@ def populate_metaRd_db(package_name, dbcon, package_path = None):
     - package_path: path the R package installation (default: None)
     """
     if package_path is None:
-        package_path = packages.get_packagepath(package_name)
+        package_path = get_packagepath(package_name)
 
     rpath = StrSexpVector((os.path.join(package_path,
                                         __package_meta),))
@@ -113,7 +114,7 @@ def populate_metaRd_db(package_name, dbcon, package_path = None):
     TITLE_I = rds.do_slot("names").index('Title')
     ENCODING_I = rds.do_slot("names").index('Encoding')
     ALIAS_I = rds.do_slot("names").index('Aliases')
-    for row_i in xrange(len(rds[0])):
+    for row_i in range(len(rds[0])):
         db_res = dbcon.execute('insert into rd_meta values (?,?,?,?,?,?,?)',
                                (row_i,
                                 rds[FILE_I][row_i], 
@@ -127,6 +128,8 @@ def populate_metaRd_db(package_name, dbcon, package_path = None):
             dbcon.execute('insert into rd_alias_meta values (?,?)',
                           (rd_rowid, alias))
 
+Item = namedtuple('Item', 'name value')
+
 class Page(object):
     """ An R documentation page. 
     The original R structure is a nested sequence of components,
@@ -140,7 +143,7 @@ class Page(object):
     """
 
     def __init__(self, struct_rdb, _type = ''):
-        sections = rlc.OrdDict()
+        sections = OrderedDict()
         for elt in struct_rdb:
             rd_tag = elt.do_slot("Rd_tag")[0][1:]
             if rd_tag == 'section':
@@ -165,9 +168,11 @@ class Page(object):
         return self.sections[item]
     
     def arguments(self):
-        """ Get the arguments and their description as a list of 2-tuples. """
-        section = self._sections['arguments']
+        """ Get the arguments and their description as a list of tuples. """
+        section = self._sections.get('arguments')
         res = list()
+        if section is None:
+            return res
         for item in section:
             if item.do_slot("Rd_tag")[0] == '\\item':
                 if len(item) != 2:
@@ -178,7 +183,7 @@ class Page(object):
                     x = x.lstrip()
                     if x.endswith('\\dots'):
                         x = '...'
-                    res.append((x, arg_desc))
+                    res.append(Item(x, arg_desc))
             else:
                 continue
         return res
@@ -285,7 +290,7 @@ class Package(object):
     def __init__(self, package_name, package_path = None):
         self.__package_name = package_name
         if package_path is None:
-            package_path = packages.get_packagepath(package_name)
+            package_path = get_packagepath(package_name)
         self.__package_path = package_path
 
         rd_meta_dbcon = sqlite3.connect(':memory:')
@@ -354,25 +359,25 @@ def pages(topic):
     """ Get help pages corresponding to a given topic. """
     res = list()
     
-    for path in packages._libpaths():
-        for name in packages._packages(**{'all.available': True, 
-                                          'lib.loc': StrSexpVector((path,))}):
+    for path in _libpaths():
+        for name in _packages(**{'all.available': True, 
+                                 'lib.loc': StrSexpVector((path,))}):
             #FIXME: what if the same package is installed
             #       at different locations ?
             pack = Package(name)
             try:
                 page = pack.fetch(topic)
                 res.append(page)
-            except HelpNotFoundError, hnfe:
+            except HelpNotFoundError as hnfe:
                 pass
             
     return tuple(res)
 
 
-def docstring(package, alias):
+def docstring(package, alias, sections=['usage', 'arguments']):
     if not isinstance(package, Package):
         package = Package(package)
     page = package.fetch(alias)
-    usage = page.section_docstring('usage')
-    arguments = page.section_docstring('arguments')
+    return page.to_docstring(sections)
+    
 
