@@ -1,5 +1,8 @@
+"""This module handles the conversion of data structures
+between R objects handled by rpy2 and pandas objects."""
+
 import os
-import pytz
+import dateutil.tz
 from datetime import datetime
 import rpy2.robjects as ro
 import rpy2.robjects.conversion as conversion
@@ -12,9 +15,12 @@ from rpy2.rinterface import (SexpVector,
 from pandas.core.frame import DataFrame as PandasDataFrame
 from pandas.core.series import Series as PandasSeries
 from pandas.core.index import Index as PandasIndex
+from pandas.core.dtypes.api import is_datetime64_any_dtype
 import pandas
 from numpy import recarray
 import numpy
+import pytz
+import tzlocal
 import warnings
 
 from collections import OrderedDict
@@ -34,7 +40,6 @@ original_converter = None
 # activate in the function activate() below
 import rpy2.robjects.numpy2ri as numpy2ri
 
-
 ISOdatetime = rinterface.baseenv['ISOdatetime']
 as_vector = rinterface.baseenv['as.vector']
 
@@ -45,9 +50,10 @@ ri2py = converter.ri2py
 ri2ro = converter.ri2ro
 
 # numpy types for Pandas columns that require (even more) special handling
-dt_datetime64ns_type = numpy.dtype('datetime64[ns]')
 dt_O_type = numpy.dtype('O')
 
+default_timezone = None
+
 @py2ri.register(PandasDataFrame)
 def py2ri_pandasdataframe(obj):
     od = OrderedDict()
@@ -80,7 +86,7 @@ def py2ri_categoryseries(obj):
     for c in obj.cat.categories:
         if not isinstance(c, str):
             raise ValueError('Converting pandas "Category" series to R factor is only possible when categories are strings.')
-    res = IntSexpVector(list(x+1 for x in obj.cat.codes))
+    res = IntSexpVector(list(rinterface.NA_Integer if x == -1 else x+1 for x in obj.cat.codes))
     res.do_slot_assign('levels', StrSexpVector(obj.cat.categories))
     if obj.cat.ordered:
         res.rclass = StrSexpVector(('ordered', 'factor'))
@@ -96,15 +102,16 @@ def py2ri_pandasseries(obj):
     elif obj.dtype.name == 'category':
         res = py2ri_categoryseries(obj)
         res = FactorVector(res)
-    elif obj.dtype == dt_datetime64ns_type:
+    elif is_datetime64_any_dtype(obj.dtype):
         # time series
+        tzname = obj.dt.tz.zone if obj.dt.tz else ''
         d = [IntVector([x.year for x in obj]),
              IntVector([x.month for x in obj]),
              IntVector([x.day for x in obj]),
              IntVector([x.hour for x in obj]),
              IntVector([x.minute for x in obj]),
              IntVector([x.second for x in obj])]
-        res = ISOdatetime(*d)
+        res = ISOdatetime(*d, tz=StrSexpVector([tzname]))
         #FIXME: can the POSIXct be created from the POSIXct constructor ?
         # (is '<M8[ns]' mapping to Python datetime.datetime ?)
         res = POSIXct(res)
@@ -146,22 +153,10 @@ def ri2py_intvector(obj):
 
 def get_timezone():
     """ Return the system's timezone settings. """
-    etc_timezone = '/etc/timezone'
-    timezone = None
-    if os.path.exists(etc_timezone):
-        try:
-            with open(etc_timezone) as fh:
-                tz = fh.read().strip()
-            try :
-                timezone = pytz.timezone(tz)
-            except pytz.UnknownTimeZoneError:
-                warnings.warn('Unknown time zone in %s, using UTC.' % etc_timezone)
-                timezone = 'UTC'
-        except IOError:
-            warnings.warn('Unable to read date in %s, using UTC.' % etc_timezone)
-            timezone = 'UTC'
+    if default_timezone:
+        timezone = default_timezone
     else:
-        warnings.warn('No file %s' % etc_timezone)
+        timezone = tzlocal.get_localzone()
     return timezone
 
 
